summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorThomas Haller <thaller@redhat.com>2021-04-01 21:40:23 +0200
committerThomas Haller <thaller@redhat.com>2021-06-10 17:48:07 +0200
commitf8624ea2e5dbe993645d9ea6c8ae68e8dd43d299 (patch)
treee03cd1e0d2ca6995211f59d9f26693f8fd031efc
parent1b97be1f34be770e01322a596f72ec3c38ae4563 (diff)
downloadNetworkManager-f8624ea2e5dbe993645d9ea6c8ae68e8dd43d299.tar.gz
contrib/scripts: use "main" branch name in "checkpatch-feature-branch.sh"
(cherry picked from commit 172dace30d5e00088d726db77f265be639c9686b)
-rwxr-xr-xcontrib/scripts/checkpatch-feature-branch.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/contrib/scripts/checkpatch-feature-branch.sh b/contrib/scripts/checkpatch-feature-branch.sh
index c46fcd4b5a..d6f72b2034 100755
--- a/contrib/scripts/checkpatch-feature-branch.sh
+++ b/contrib/scripts/checkpatch-feature-branch.sh
@@ -23,23 +23,23 @@ else
git fetch origin "$(git rev-parse "$HEAD")" --no-tags --unshallow
git fetch "$NM_UPSTREAM_REMOTE" \
--no-tags \
- "refs/heads/master:$BASE_REF/master" \
+ "refs/heads/main:$BASE_REF/main" \
"refs/heads/nm-*:$BASE_REF/nm-*" \
|| die "failure to fetch from https://gitlab.freedesktop.org/NetworkManager/NetworkManager.git"
fi
# the argument is only a single ref (or the default "HEAD").
# Find all commits that branch off one of the stable branches or master
# and lead to $HEAD. These are the commits of the feature branch.
- RANGES=( $(git show-ref | sed 's#^\(.*\) '"$BASE_REF/"'\(master\|nm-1-[0-9]\+\)$#\1..'"$HEAD"'#p' -n) )
+ RANGES=( $(git show-ref | sed 's#^\(.*\) '"$BASE_REF/"'\(main\|nm-1-[0-9]\+\)$#\1..'"$HEAD"'#p' -n) )
[ "${#RANGES[@]}" != 0 ] || die "cannot detect git-ranges (HEAD is $(git rev-parse "$HEAD"))"
REFS=( $(git log --reverse --format='%H' "${RANGES[@]}") )
if [ "${#REFS[@]}" == 0 ] ; then
# no refs detected. This means, $HEAD is already on master (or one of the
# stable nm-1-* branches. Just check the patch itself.
REFS=( "$HEAD" )
fi
@@ -23,23 +23,23 @@ else
fi
# the argument is only a single ref (or the default "HEAD").
- # Find all commits that branch off one of the stable branches or master
+ # Find all commits that branch off one of the stable branches or main
# and lead to $HEAD. These are the commits of the feature branch.
@@ -23,23 +23,23 @@ else
REFS=( $(git log --reverse --format='%H' "${RANGES[@]}") )
if [ "${#REFS[@]}" == 0 ] ; then
- # no refs detected. This means, $HEAD is already on master (or one of the
+ # no refs detected. This means, $HEAD is already on main (or one of the
# stable nm-1-* branches. Just check the patch itself.
REFS=( "$HEAD" )